package Bundle::IkiWiki;

$VERSION = '0.01';

1;

__END__

=head1 NAME

Bundle::IkiWiki - core modules that ikiwiki needs

=head1 SYNOPSIS

perl -MCPAN -e 'install Bundle::IkiWiki'

=head1 CONTENTS

Text::Markdown
HTML::Scrubber
HTML::Template
HTML::Parser
URI 1.36
XML::Simple
Date::Parse
CGI::FormBuilder
CGI::Session
Mail::Sendmail
CGI
Data::Dumper

=head1 AUTHOR

Joey Hess <joey@ikiwiki.info>
